# Astoria

![Tests](https://github.com/srobo/astoria/workflows/Tests/badge.svg)
![Build and Publish docs](https://github.com/srobo/astoria/workflows/Build%20and%20Publish%20docs/badge.svg)
[![PyPI version](https://badge.fury.io/py/astoria.svg)](https://badge.fury.io/py/astoria)
[![MIT license](https://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat)](https://opensource.org/licenses/MIT)
![Bees](https://img.shields.io/badge/bees-110%25-yellow.svg)

Robot Management System for Student Robotics 2022 kit.

For more information, please see the [documentation](https://srobo.github.io/astoria).

## Contributions

This project is released under the MIT Licence. For more information, please see LICENSE.

The CONTRIBUTORS file can be generated by executing CONTRIBUTORS.gen. This generated file contains a list of people who have contributed to Astoria.

